@@ -37,6 +37,12 @@ hidden_imports = [
     "ics.structures.extended_response_generic",
     "ics.structures.get_supported_features_response",
     "ics.structures.s_ext_sub_cmd_hdr",
+    "ics.structures.timestamp_",
+    "ics.structures.port_identity",
+    "ics.structures.clock_quality_",
+    "ics.structures.system_identity",
+    "ics.structures.priority_vector",
+    "ics.structures.gptp_status",
     "ics.structures.s_ext_sub_cmd_comm",
     "ics.structures.serdescam_settings",
     "ics.structures.serdespoc_settings",
@@ -91,11 +97,17 @@ hidden_imports = [
     "ics.structures.s_flex_vnetz_settings",
     "ics.structures.s_neo_ecu12_settings",
     "ics.structures.svcan4_ind_settings",
+    "ics.structures.sobd2_lc_settings",
+    "ics.structures.s_jupiter_ptp_params_s",
     "ics.structures.srad_jupiter_switch_settings",
     "ics.structures.srad_jupiter_settings",
     "ics.structures.s_fire3_settings",
     "ics.structures.s_rad_moon_duo_settings",
     "ics.structures.s_ether_badge_settings",
+    "ics.structures.srad_epsilon_switch_settings",
+    "ics.structures.srad_epsilon_settings",
+    "ics.structures.swil_bridge_config",
+    "ics.structures.sradbms_settings",
     "ics.structures.global_settings",
     "ics.structures.s_device_settings",
     "ics.structures.st_cm_iso157652_tx_message",
@@ -116,6 +128,8 @@ hidden_imports = [
     "ics.structures.ics_obd2_pro_device_status",
     "ics.structures.ics_rad_pluto_device_status",
     "ics.structures.ics_vcan4_industrial_device_status",
+    "ics.structures.ics_rad_epsilon_device_status",
+    "ics.structures.ics_rad_bms_device_status",
     "ics.structures.ics_device_status",
     "ics.structures.ndis_adapter_information",
     "ics.structures.s_phy_reg_pkt_hdr",
@@ -129,6 +143,7 @@ hidden_imports = [
     "ics.structures.e_gptp_port",
     "ics.structures.e_gptp_role",
     "ics.structures.a2_btdm_mode",
+    "ics.structures.a2_b_node_type",
     "ics.structures.flex_vnet_mode",
     "ics.structures.e_device_settings_type",
     "ics.structures.e_plasma_ion_vnet_channel_t",
