@@ -37,6 +37,12 @@ __all__ = [
     "extended_response_generic",
     "get_supported_features_response",
     "s_ext_sub_cmd_hdr",
+    "timestamp_",
+    "port_identity",
+    "clock_quality_",
+    "system_identity",
+    "priority_vector",
+    "gptp_status",
     "s_ext_sub_cmd_comm",
     "serdescam_settings",
     "serdespoc_settings",
@@ -91,11 +97,17 @@ __all__ = [
     "s_flex_vnetz_settings",
     "s_neo_ecu12_settings",
     "svcan4_ind_settings",
+    "sobd2_lc_settings",
+    "s_jupiter_ptp_params_s",
     "srad_jupiter_switch_settings",
     "srad_jupiter_settings",
     "s_fire3_settings",
     "s_rad_moon_duo_settings",
     "s_ether_badge_settings",
+    "srad_epsilon_switch_settings",
+    "srad_epsilon_settings",
+    "swil_bridge_config",
+    "sradbms_settings",
     "global_settings",
     "s_device_settings",
     "st_cm_iso157652_tx_message",
@@ -116,6 +128,8 @@ __all__ = [
     "ics_obd2_pro_device_status",
     "ics_rad_pluto_device_status",
     "ics_vcan4_industrial_device_status",
+    "ics_rad_epsilon_device_status",
+    "ics_rad_bms_device_status",
     "ics_device_status",
     "ndis_adapter_information",
     "s_phy_reg_pkt_hdr",
@@ -129,6 +143,7 @@ __all__ = [
     "e_gptp_port",
     "e_gptp_role",
     "a2_btdm_mode",
+    "a2_b_node_type",
     "flex_vnet_mode",
     "e_device_settings_type",
     "e_plasma_ion_vnet_channel_t",
